#!/bin/bash

PACKAGE_NAME="icinga1-objects-upgrader"

# Enter source directory
cd $( dirname $0 )

# Clean previous build
rm -fr dist deb_dist setup.py release-notes.md

# Compute version using git describe
VERSION="$( git describe --tags 2> /dev/null )"

# If no tag exist, git describe will fail: in this case, compute a 0.0 version with same format
# as git describe
[ $? -ne 0 ] && VERSION="0.0-$( git log|grep -cE ^'commit ' )-$( git describe --tags --always )"

# Fix version format to match with Python specs
# See: https://peps.python.org/pep-0440/
VERSION=$( echo "$VERSION"|sed 's/[^0-9]*\([0-9][^-]*\)-\(.*\)/\1+\2/' )

# Set version in pyproject.toml
sed -i "s/^version *=.*$/version = \"$VERSION\"/" pyproject.toml

# Compute debian package version by adding EE debian version suffix
DEB_VERSION_SUFFIX="~ee$( lsb_release -r -s )0+1"
DEB_VERSION="${VERSION}${DEB_VERSION_SUFFIX}"

if [ -d venv ]
then
	VENV=$( realpath venv )
	TEMP_VENV=0
else
	# Install dephell & stdeb in temporary venv
	VENV=$(mktemp -d)
	echo "Create a temporary virtualenv in $VENV to install build dependencies..."
	TEMP_VENV=1
	python3 -m venv $VENV
	# Fix dephell dependencies: Install specific version of mistune and docutils
        # to fix m2r issues (https//github.com/miyakogi/m2r/issues/66) and install
        # missing appdirs dependency
	$VENV/bin/python3 -m pip install mistune==0.8.4 docutils==0.18.1 appdirs
	$VENV/bin/python3 -m pip install dephell stdeb GitPython argcomplete
fi

# Install poetry and build python whl package
$VENV/bin/python3 -m pip install poetry
export POETRY_VIRTUALENVS_PATH=$VENV
$VENV/bin/poetry build
unset POETRY_VIRTUALENVS_PATH

# Check gitdch is installed
GITDCH=$(which gitdch)
set -e
if [ -z "$GITDCH" ]
then
        TMP_GITDCH=$(mktemp -d)
        echo "Temporary install gitdch in $TMP_GITDCH"
        git clone https://gitea.zionetrix.net/bn8/gitdch.git $TMP_GITDCH/gitdch
        GITDCH=$TMP_GITDCH/gitdch/gitdch
else
        TMP_GITDCH=""
fi

# Convert pyproject.toml to setup.py (using dephell)
$VENV/bin/dephell deps convert \
	--from-format poetry --to-format setuppy \
	--from-path pyproject.toml --to-path setup.py

# Build debian source package
$VENV/bin/python3 setup.py --command-packages=stdeb.command sdist_dsc \
	--package3 "$PACKAGE_NAME" \
	--maintainer "Benjamin Renard <brenard@easter-eggs.com>" \
	--compat 10 \
	--section net \
	--forced-upstream-version "$DEB_VERSION"

# Keep only debian package directory and orig.tar.gz archive
find deb_dist/ -maxdepth 1 -type f ! -name '*.orig.tar.gz' -delete

# Enter in debian package directory
cd deb_dist/$PACKAGE_NAME-$DEB_VERSION

# Generate EE debian codename
DEBIAN_CODENAME=$( lsb_release -c -s )
[ $( lsb_release -r -s ) -ge 9 ] && DEBIAN_CODENAME="${DEBIAN_CODENAME}-ee"

# Generate debian changelog using generate_debian_changelog.py
$VENV/bin/python3 $GITDCH \
	--package-name $PACKAGE_NAME \
	--version "${DEB_VERSION}" \
	--version-suffix "${DEB_VERSION_SUFFIX}" \
	--code-name $DEBIAN_CODENAME \
	--output debian/changelog \
	--release-notes ../../release-notes.md \
	--path ../../ \
	--verbose

# Generate bash completion file
$VENV/bin/register-python-argcomplete icinga1_objects_upgrader > debian/bash-completion
sed -i 's/\(dh \$@.*\)/\1 --with bash-completion/' debian/rules

[ $TEMP_VENV -eq 1 ] && rm -fr $VENV

# Clean temporary gitdch installation
[ -n "$TMP_GITDCH" ] && rm -fr $TMP_GITDCH

# Build debian package
dpkg-buildpackage --no-sign
